# CI for Empty Cookiecutters

Cookiecutters for taps and targets include two kinds of tests: linting and end-to-end testing with pytest. When a new project is created with the cookiecutter we expect:

- linting tests should pass
- integration tests may fail (because no integration has been implemented yet)

To automate creation of cookiecutter test projects, we use a [replay file](https://cookiecutter.readthedocs.io/en/stable/advanced/replay.html) generated by cookiecutter.

## Running Manually

Run a test against tap-template cookiecutter against the `tap-rest-api_key-github.json` replay file, execute:

```bash
bash test_cookiecutter.sh ../../cookiecutter/tap-template ./tap-rest-api_key-github.json
bash test_cookiecutter.sh ../../cookiecutter/target-template ./target-per_record.json
```
